<template>
   <div class="app-container">
      <el-form :model="queryParams" ref="queryRef" :inline="true" v-show="showSearch">
         <el-form-item label="区域名称" prop="deptName">
            <el-input v-model="queryParams.deptName" placeholder="请输入区域名称" clearable style="width: 200px"
               @keyup.enter="handleQuery" />
         </el-form-item>
         <el-form-item label="状态" prop="status">
            <el-select v-model="queryParams.status" placeholder="区域状态" clearable style="width: 200px">
               <el-option v-for="dict in sys_normal_disable" :key="dict.value" :label="dict.label"
                  :value="dict.value" />
            </el-select>
         </el-form-item>
         <el-form-item>
            <el-button type="primary" icon="Search" @click="handleQuery">搜索</el-button>
            <el-button icon="Refresh" @click="resetQuery">重置</el-button>
         </el-form-item>
      </el-form>

      <el-row :gutter="10" class="mb8">
         <el-col :span="1.5">
            <el-button type="primary" plain icon="Plus" @click="handleAdd"
               v-hasPermi="['system:dept:add']">新增</el-button>
         </el-col>
         <el-col :span="1.5">
            <el-button type="info" plain icon="Sort" @click="toggleExpandAll">展开/折叠</el-button>
         </el-col>
         <right-toolbar v-model:showSearch="showSearch" @queryTable="getList"></right-toolbar>
      </el-row>

      <el-table v-if="refreshTable" v-loading="loading" :data="deptList" row-key="deptId"
         :default-expand-all="isExpandAll" :tree-props="{ children: 'children', hasChildren: 'hasChildren' }">
         <el-table-column prop="deptName" label="区域名称" width="260"></el-table-column>
         <el-table-column prop="orderNum" label="排序"></el-table-column>
         <el-table-column prop="provinceName" label="省级"></el-table-column>
         <el-table-column prop="cityName" label="市级"></el-table-column>
         <el-table-column prop="districtName" label="区级"></el-table-column>
         <el-table-column prop="distributionRatio" label="分账比例"></el-table-column>
         <el-table-column prop="areaType" label="类型">
            <template #default="scope">
               <dict-tag :options="jlzj_area_type" :value="scope.row.areaType" />
            </template>
         </el-table-column>


         <el-table-column prop="status" label="状态" width="80">
            <template #default="scope">
               <dict-tag :options="sys_normal_disable" :value="scope.row.status" />
            </template>
         </el-table-column>
         <el-table-column label="创建时间" align="center" prop="createTime">
            <template #default="scope">
               <span>{{ parseTime(scope.row.createTime) }}</span>
            </template>
         </el-table-column>
         <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
            <template #default="scope">
               <el-button link type="primary" icon="Edit" @click="handleUpdate(scope.row)"
                  v-hasPermi="['system:dept:edit']">修改</el-button>
               <el-button link type="primary" icon="Plus" @click="handleAdd(scope.row)"
                  v-hasPermi="['system:dept:add']">新增</el-button>
               <el-button v-if="scope.row.parentId != 0" link type="primary" icon="Delete"
                  @click="handleDelete(scope.row)" v-hasPermi="['system:dept:remove']">删除</el-button>
               <!-- <el-button link type="primary" icon="Setting" @click="handleSetting(scope.row)">区域设置</el-button> -->
            </template>
         </el-table-column>
      </el-table>

      <!-- 添加或修改区域对话框 -->
      <el-dialog :title="title" v-model="open" width="600px" append-to-body>
         <el-form ref="deptRef" :model="form" :rules="rules" label-width="80px">
            <el-row>
               <el-col :span="24" v-if="form.parentId !== 0">
                  <el-form-item label="上级区域" prop="parentId">
                     <el-tree-select v-model="form.parentId" :data="deptOptions"
                        :props="{ value: 'deptId', label: 'deptName', children: 'children' }" value-key="deptId"
                        placeholder="选择上级区域" check-strictly />
                  </el-form-item>
               </el-col>
               <el-col :span="24">
                  <el-form-item label="省级" prop="provinceCode">
                     <el-select v-model="form.provinceCode" placeholder="请选择省级" clearable @change="provinceChange">
                        <el-option v-for="dict in province" :key="dict.code" :label="dict.name"
                           :value="dict.code"></el-option>
                     </el-select>
                  </el-form-item>
               </el-col>
               <el-col :span="24">
                  <el-form-item label="市级" prop="cityCode">
                     <el-select v-model="form.cityCode" placeholder="请选择市级" clearable @change="cityChange">
                        <el-option v-for="dict in city" :key="dict.code" :label="dict.name"
                           :value="dict.code"></el-option>
                     </el-select>
                  </el-form-item>
               </el-col>
               <el-col :span="24">
                  <el-form-item label="区级" prop="districtCode">
                     <el-select v-model="form.districtCode" placeholder="请选择区级" clearable @change="districtChange">
                        <el-option v-for="dict in district" :key="dict.code" :label="dict.name"
                           :value="dict.code"></el-option>
                     </el-select>
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="区域名称" prop="deptName">
                     <el-input v-model="form.deptName" placeholder="请输入区域名称" />
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="显示排序" prop="orderNum">
                     <el-input-number v-model="form.orderNum" controls-position="right" :min="0" />
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="负责人" prop="leader">
                     <el-input v-model="form.leader" placeholder="请输入负责人" maxlength="20" />
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="联系电话" prop="phone">
                     <el-input v-model="form.phone" placeholder="请输入联系电话" maxlength="11" />
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="邮箱" prop="email">
                     <el-input v-model="form.email" placeholder="请输入邮箱" maxlength="50" />
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="区域状态">
                     <el-radio-group v-model="form.status">
                        <el-radio v-for="dict in sys_normal_disable" :key="dict.value" :value="dict.value">{{ dict.label
                        }}</el-radio>
                     </el-radio-group>
                  </el-form-item>
               </el-col>


               <el-col :span="12">
                  <el-form-item label="分账比例" prop="distributionRatio">
                     <el-input v-model="form.distributionRatio" placeholder="请输入分账比例" maxlength="50" type="number"
                        :step="0.1" :min="0" :max="1">
                        <!-- <template #append>%</template> -->
                     </el-input>
                  </el-form-item>
               </el-col>
               <el-col :span="12">
                  <el-form-item label="状态">
                     <el-radio-group v-model="form.areaType">
                        <el-radio v-for="dict in jlzj_area_type" :key="dict.value" :value="dict.value">{{ dict.label
                        }}</el-radio>
                     </el-radio-group>
                  </el-form-item>
               </el-col>

            </el-row>
         </el-form>
         <template #footer>
            <div class="dialog-footer">
               <el-button type="primary" @click="submitForm">确 定</el-button>
               <el-button @click="cancel">取 消</el-button>
            </div>
         </template>
      </el-dialog>
   </div>
</template>

<script setup name="Dept">
import { listDept, getDept, delDept, addDept, updateDept, listDeptExcludeChild } from "@/api/system/dept";
import address from "./address";
const router = useRouter();
const { proxy } = getCurrentInstance();
const { sys_normal_disable, jlzj_area_type } = proxy.useDict("sys_normal_disable", "jlzj_area_type");

const deptList = ref([]);
const open = ref(false);
const loading = ref(true);
const showSearch = ref(true);
const title = ref("");
const deptOptions = ref([]);
const isExpandAll = ref(true);
const refreshTable = ref(true);

const data = reactive({
   form: {
      distributionRatio: 0
   },
   queryParams: {
      deptName: undefined,
      status: undefined
   },
   rules: {
      parentId: [{ required: true, message: "上级区域不能为空", trigger: "blur" }],
      deptName: [{ required: true, message: "区域名称不能为空", trigger: "blur" }],
      orderNum: [{ required: true, message: "显示排序不能为空", trigger: "blur" }],
      email: [{ type: "email", message: "请输入正确的邮箱地址", trigger: ["blur", "change"] }],
      phone: [{ pattern: /^1[3|4|5|6|7|8|9][0-9]\d{8}$/, message: "请输入正确的手机号码", trigger: "blur" }],
      provinceCode: [{ required: true, message: "所属省级区域不能为空", trigger: "blur" }],
      //  cityCode: [{ required: true, message: "所属市级区域不能为空", trigger: "blur" }],
      //  districtCode: [{ required: true, message: "所属区级区域不能为空", trigger: "blur" }],
   },
});

const areaOption = reactive({
   province: [], //省
   city: [],//市
   district: []//区
})
const { province, city, district } = toRefs(areaOption);
const { queryParams, form, rules } = toRefs(data);

/** 查询区域列表 */
function getList() {
   loading.value = true;
   listDept(queryParams.value).then(response => {
      deptList.value = proxy.handleTree(response.data, "deptId");
      console.log('deptList:', deptList.value);
      loading.value = false;
   });
}

/** 取消按钮 */
function cancel() {
   open.value = false;
   province.value = [];
   city.value = [];
   district.value = [];
   reset();
}

/** 表单重置 */
function reset() {
   form.value = {
      deptId: undefined,
      parentId: undefined,
      deptName: undefined,
      orderNum: 0,
      leader: undefined,
      phone: undefined,
      email: undefined,
      status: "0",
      distributionRatio: 0
   };
   proxy.resetForm("deptRef");
}

/** 搜索按钮操作 */
function handleQuery() {
   getList();
}

/** 重置按钮操作 */
function resetQuery() {
   proxy.resetForm("queryRef");
   handleQuery();
}

/** 新增按钮操作 */
function handleAdd(row) {
   reset();
   listDept().then(response => {
      deptOptions.value = proxy.handleTree(response.data, "deptId");
   });
   if (row != undefined) {
      form.value.parentId = row.deptId;
   }
   open.value = true;
   title.value = "添加区域";

   province.value = address;
}

/** 展开/折叠操作 */
function toggleExpandAll() {
   refreshTable.value = false;
   isExpandAll.value = !isExpandAll.value;
   nextTick(() => {
      refreshTable.value = true;
   });
}

/** 修改按钮操作 */
function handleUpdate(row) {
   reset();
   province.value = address;
   listDeptExcludeChild(row.deptId).then(response => {
      deptOptions.value = proxy.handleTree(response.data, "deptId");
   });
   getDept(row.deptId).then(response => {
      form.value = {
         ...response.data,
         provinceCode: response.data.provinceCode ? Number(response.data.provinceCode) : null,
         cityCode: response.data.cityCode ? Number(response.data.cityCode) : null,
         districtCode: response.data.districtCode ? Number(response.data.districtCode) : null
      }
      handleAreaOption();
      open.value = true;
      title.value = "修改区域";
   });
}

/** 提交按钮 */
function submitForm() {
   proxy.$refs["deptRef"].validate(valid => {
      if (valid) {
         if (form.value.distributionRatio) {
            form.value.distributionRatio = Number(form.value.distributionRatio);
         }
         if (form.value.deptId != undefined) {
            updateDept(form.value).then(response => {
               proxy.$modal.msgSuccess("修改成功");
               open.value = false;
               getList();
            });
         } else {
            addDept(form.value).then(response => {
               proxy.$modal.msgSuccess("新增成功");
               open.value = false;
               getList();
            });
         }
      }
   });
}

/** 删除按钮操作 */
function handleDelete(row) {
   proxy.$modal.confirm('是否确认删除名称为"' + row.deptName + '"的数据项?').then(function () {
      return delDept(row.deptId);
   }).then(() => {
      getList();
      proxy.$modal.msgSuccess("删除成功");
   }).catch(() => { });
}

function handleSetting(row) {
   if (!row.pointList) row.pointList = JSON.stringify([]) // 如果pointList为空，则设置为空数组
   console.log(row, '>>>>>>row000009999');


   const coordinate = row ? JSON.stringify(row) : '[]'
   localStorage.setItem('mapDeptRow', coordinate);
   router.push({ path: '/map-setting', query: { deptId: row.deptId } });
}

function handleAreaOption() {
   province.value = address;
   if (form.value.cityCode && form.value.provinceCode) {
      const option = province.value.find(item => item.code === form.value.provinceCode);
      city.value = option.children ? option.children : []
   }
   if (form.value.districtCode && form.value.cityCode) {
      const option = city.value.find(item => item.code === form.value.cityCode);
      district.value = option.children ? option.children : []
   }
}


function provinceChange(record) {
   const option = province.value.find(item => item.code === record);
   form.value.provinceName = option.name;
   city.value = option.children ? option.children : []
   district.value = [];
}
function cityChange(record) {
   const option = city.value.find(item => item.code === record);
   form.value.cityName = option.name;
   district.value = option.children ? option.children : []
}

function districtChange(record) {
   const option = district.value.find(item => item.code === record);
   form.value.districtName = option.name;
}
getList();
handleAreaOption()
</script>
